@@ -77,14 +77,14 @@ void printBasket(
         Real vol = helper->volatility()->value();
         Real rate = helper->underlyingSwap()->fixedRate();
         Date expiry = helper->swaption()->exercise()->date(0);
-        VanillaSwap::Type type = helper->swaption()->type();
+        Swap::Type type = helper->swaption()->type();
         std::ostringstream expiryString, endDateString;
         expiryString << expiry;
         endDateString << endDate;
         std::cout << std::setw(20) << expiryString.str() << std::setw(20)
                   << endDateString.str() << std::setw(20) << nominal
                   << std::setw(14) << rate << std::setw(12)
-                  << (type == VanillaSwap::Payer ? "Payer" : "Receiver")
+                  << (type == Swap::Payer ? "Payer" : "Receiver")
                   << std::setw(14) << vol << std::endl;
     }
 }
@@ -193,7 +193,7 @@ int main(int argc, char *argv[]) {
 
         ext::shared_ptr<NonstandardSwap> underlying =
             ext::make_shared<NonstandardSwap>(VanillaSwap(
-                VanillaSwap::Payer, 1.0, fixedSchedule, strike, Thirty360(),
+                Swap::Payer, 1.0, fixedSchedule, strike, Thirty360(Thirty360::BondBasis),
                 floatingSchedule, euribor6m, 0.00, Actual360()));
 
         std::vector<Date> exerciseDates;
@@ -355,8 +355,8 @@ int main(int argc, char *argv[]) {
         std::vector<Real> strikes(nominalFixed.size(), strike);
 
         ext::shared_ptr<NonstandardSwap> underlying2(new NonstandardSwap(
-            VanillaSwap::Payer, nominalFixed, nominalFloating, fixedSchedule,
-            strikes, Thirty360(), floatingSchedule, euribor6m, 1.0, 0.0,
+            Swap::Payer, nominalFixed, nominalFloating, fixedSchedule,
+            strikes, Thirty360(Thirty360::BondBasis), floatingSchedule, euribor6m, 1.0, 0.0,
             Actual360()));
         ext::shared_ptr<NonstandardSwaption> swaption2 =
             ext::make_shared<NonstandardSwaption>(underlying2, exercise);
@@ -391,8 +391,8 @@ int main(int argc, char *argv[]) {
                                            0.0); // null the second leg
 
         ext::shared_ptr<NonstandardSwap> underlying3(new NonstandardSwap(
-            VanillaSwap::Receiver, nominalFixed2, nominalFloating2,
-            fixedSchedule, strikes, Thirty360(), floatingSchedule, euribor6m,
+            Swap::Receiver, nominalFixed2, nominalFloating2,
+            fixedSchedule, strikes, Thirty360(Thirty360::BondBasis), floatingSchedule, euribor6m,
             1.0, 0.0, Actual360(), false,
             true)); // final capital exchange
 
@@ -486,8 +486,8 @@ int main(int argc, char *argv[]) {
                "\nis exercisable on a yearly basis" << std::endl;
 
         ext::shared_ptr<FloatFloatSwap> underlying4(new FloatFloatSwap(
-                VanillaSwap::Payer, 1.0, 1.0, fixedSchedule, swapBase,
-                Thirty360(), floatingSchedule, euribor6m, Actual360(), false,
+                Swap::Payer, 1.0, 1.0, fixedSchedule, swapBase,
+                Thirty360(Thirty360::BondBasis), floatingSchedule, euribor6m, Actual360(), false,
                 false, 1.0, 0.0, Null<Real>(), Null<Real>(), 1.0, 0.0010));
 
         ext::shared_ptr<FloatFloatSwaption> swaption4 =
