@@ -20,19 +20,18 @@
  FOR A PARTICULAR PURPOSE.  See the license for more details.
 */
 
-#include <ql/cashflows/couponpricer.hpp>
 #include <ql/cashflows/capflooredcoupon.hpp>
-#include <ql/cashflows/digitalcoupon.hpp>
+#include <ql/cashflows/couponpricer.hpp>
 #include <ql/cashflows/digitalcmscoupon.hpp>
+#include <ql/cashflows/digitalcoupon.hpp>
 #include <ql/cashflows/digitaliborcoupon.hpp>
 #include <ql/cashflows/rangeaccrual.hpp>
-#include <ql/experimental/coupons/subperiodcoupons.hpp> /* internal */
-#include <ql/experimental/coupons/cmsspreadcoupon.hpp>  /* internal */
-#include <ql/experimental/coupons/digitalcmsspreadcoupon.hpp>  /* internal */
+#include <ql/cashflows/subperiodcoupon.hpp>
+#include <ql/experimental/coupons/cmsspreadcoupon.hpp>        /* internal */
+#include <ql/experimental/coupons/digitalcmsspreadcoupon.hpp> /* internal */
 #include <ql/pricingengines/blackformula.hpp>
 #include <ql/termstructures/yieldtermstructure.hpp>
-
-using boost::dynamic_pointer_cast;
+#include <utility>
 
 namespace QuantLib {
 
@@ -47,10 +46,10 @@ namespace QuantLib {
         accrualPeriod_ = coupon.accrualPeriod();
         QL_REQUIRE(accrualPeriod_ != 0.0, "null accrual period");
 
-        index_ = dynamic_pointer_cast<IborIndex>(coupon.index());
+        index_ = ext::dynamic_pointer_cast<IborIndex>(coupon.index());
         if (!index_) {
             // check if the coupon was right
-            const IborCoupon* c = dynamic_cast<const IborCoupon*>(&coupon);
+            const auto* c = dynamic_cast<const IborCoupon*>(&coupon);
             QL_REQUIRE(c, "IborCoupon required");
             // coupon was right, index is not
             QL_FAIL("IborIndex required");
@@ -188,27 +187,26 @@ namespace QuantLib {
                              public Visitor<RangeAccrualFloatersCoupon>,
                              public Visitor<SubPeriodsCoupon> {
           private:
-            boost::shared_ptr<FloatingRateCouponPricer> pricer_;
+            ext::shared_ptr<FloatingRateCouponPricer> pricer_;
           public:
-            explicit PricerSetter(
-                    const boost::shared_ptr<FloatingRateCouponPricer>& pricer)
-            : pricer_(pricer) {}
+            explicit PricerSetter(ext::shared_ptr<FloatingRateCouponPricer> pricer)
+            : pricer_(std::move(pricer)) {}
 
-            void visit(CashFlow& c);
-            void visit(Coupon& c);
-            void visit(FloatingRateCoupon& c);
-            void visit(CappedFlooredCoupon& c);
-            void visit(IborCoupon& c);
-            void visit(CappedFlooredIborCoupon& c);
-            void visit(DigitalIborCoupon& c);
-            void visit(CmsCoupon& c);
-            void visit(CmsSpreadCoupon& c);
-            void visit(CappedFlooredCmsCoupon& c);
-            void visit(CappedFlooredCmsSpreadCoupon& c);
-            void visit(DigitalCmsCoupon& c);
-            void visit(DigitalCmsSpreadCoupon& c);
-            void visit(RangeAccrualFloatersCoupon& c);
-            void visit(SubPeriodsCoupon& c);
+            void visit(CashFlow& c) override;
+            void visit(Coupon& c) override;
+            void visit(FloatingRateCoupon& c) override;
+            void visit(CappedFlooredCoupon& c) override;
+            void visit(IborCoupon& c) override;
+            void visit(CappedFlooredIborCoupon& c) override;
+            void visit(DigitalIborCoupon& c) override;
+            void visit(CmsCoupon& c) override;
+            void visit(CmsSpreadCoupon& c) override;
+            void visit(CappedFlooredCmsCoupon& c) override;
+            void visit(CappedFlooredCmsSpreadCoupon& c) override;
+            void visit(DigitalCmsCoupon& c) override;
+            void visit(DigitalCmsSpreadCoupon& c) override;
+            void visit(RangeAccrualFloatersCoupon& c) override;
+            void visit(SubPeriodsCoupon& c) override;
         };
 
         void PricerSetter::visit(CashFlow&) {
@@ -227,118 +225,119 @@ namespace QuantLib {
             // we might end up here because a CappedFlooredCoupon
             // was directly constructed; we should then check
             // the underlying for consistency with the pricer
-            if (boost::dynamic_pointer_cast<IborCoupon>(c.underlying())) {
-                QL_REQUIRE(boost::dynamic_pointer_cast<IborCouponPricer>(pricer_),
+            if (ext::dynamic_pointer_cast<IborCoupon>(c.underlying()) != nullptr) {
+                QL_REQUIRE(ext::dynamic_pointer_cast<IborCouponPricer>(pricer_),
                            "pricer not compatible with Ibor Coupon");
-            } else if (boost::dynamic_pointer_cast<CmsCoupon>(c.underlying())) {
-                QL_REQUIRE(boost::dynamic_pointer_cast<CmsCouponPricer>(pricer_),
+            } else if (ext::dynamic_pointer_cast<CmsCoupon>(c.underlying()) != nullptr) {
+                QL_REQUIRE(ext::dynamic_pointer_cast<CmsCouponPricer>(pricer_),
                            "pricer not compatible with CMS Coupon");
-            } else if (boost::dynamic_pointer_cast<CmsSpreadCoupon>(c.underlying())) {
-                QL_REQUIRE(boost::dynamic_pointer_cast<CmsSpreadCouponPricer>(pricer_),
+            } else if (ext::dynamic_pointer_cast<CmsSpreadCoupon>(c.underlying()) != nullptr) {
+                QL_REQUIRE(ext::dynamic_pointer_cast<CmsSpreadCouponPricer>(pricer_),
                            "pricer not compatible with CMS spread Coupon");
             }
             c.setPricer(pricer_);
         }
 
         void PricerSetter::visit(IborCoupon& c) {
-            const boost::shared_ptr<IborCouponPricer> iborCouponPricer =
-                boost::dynamic_pointer_cast<IborCouponPricer>(pricer_);
+            const ext::shared_ptr<IborCouponPricer> iborCouponPricer =
+                ext::dynamic_pointer_cast<IborCouponPricer>(pricer_);
             QL_REQUIRE(iborCouponPricer,
                        "pricer not compatible with Ibor coupon");
             c.setPricer(iborCouponPricer);
         }
 
         void PricerSetter::visit(DigitalIborCoupon& c) {
-            const boost::shared_ptr<IborCouponPricer> iborCouponPricer =
-                boost::dynamic_pointer_cast<IborCouponPricer>(pricer_);
+            const ext::shared_ptr<IborCouponPricer> iborCouponPricer =
+                ext::dynamic_pointer_cast<IborCouponPricer>(pricer_);
             QL_REQUIRE(iborCouponPricer,
                        "pricer not compatible with Ibor coupon");
             c.setPricer(iborCouponPricer);
         }
 
         void PricerSetter::visit(CappedFlooredIborCoupon& c) {
-            const boost::shared_ptr<IborCouponPricer> iborCouponPricer =
-                boost::dynamic_pointer_cast<IborCouponPricer>(pricer_);
+            const ext::shared_ptr<IborCouponPricer> iborCouponPricer =
+                ext::dynamic_pointer_cast<IborCouponPricer>(pricer_);
             QL_REQUIRE(iborCouponPricer,
                        "pricer not compatible with Ibor coupon");
             c.setPricer(iborCouponPricer);
         }
 
         void PricerSetter::visit(CmsCoupon& c) {
-            const boost::shared_ptr<CmsCouponPricer> cmsCouponPricer =
-                boost::dynamic_pointer_cast<CmsCouponPricer>(pricer_);
+            const ext::shared_ptr<CmsCouponPricer> cmsCouponPricer =
+                ext::dynamic_pointer_cast<CmsCouponPricer>(pricer_);
             QL_REQUIRE(cmsCouponPricer,
                        "pricer not compatible with CMS coupon");
             c.setPricer(cmsCouponPricer);
         }
 
         void PricerSetter::visit(CmsSpreadCoupon& c) {
-            const boost::shared_ptr<CmsSpreadCouponPricer> cmsSpreadCouponPricer =
-                boost::dynamic_pointer_cast<CmsSpreadCouponPricer>(pricer_);
+            const ext::shared_ptr<CmsSpreadCouponPricer> cmsSpreadCouponPricer =
+                ext::dynamic_pointer_cast<CmsSpreadCouponPricer>(pricer_);
             QL_REQUIRE(cmsSpreadCouponPricer,
                        "pricer not compatible with CMS spread coupon");
             c.setPricer(cmsSpreadCouponPricer);
         }
 
         void PricerSetter::visit(CappedFlooredCmsCoupon& c) {
-            const boost::shared_ptr<CmsCouponPricer> cmsCouponPricer =
-                boost::dynamic_pointer_cast<CmsCouponPricer>(pricer_);
+            const ext::shared_ptr<CmsCouponPricer> cmsCouponPricer =
+                ext::dynamic_pointer_cast<CmsCouponPricer>(pricer_);
             QL_REQUIRE(cmsCouponPricer,
                        "pricer not compatible with CMS coupon");
             c.setPricer(cmsCouponPricer);
         }
 
         void PricerSetter::visit(CappedFlooredCmsSpreadCoupon& c) {
-            const boost::shared_ptr<CmsSpreadCouponPricer> cmsSpreadCouponPricer =
-                boost::dynamic_pointer_cast<CmsSpreadCouponPricer>(pricer_);
+            const ext::shared_ptr<CmsSpreadCouponPricer> cmsSpreadCouponPricer =
+                ext::dynamic_pointer_cast<CmsSpreadCouponPricer>(pricer_);
             QL_REQUIRE(cmsSpreadCouponPricer,
                        "pricer not compatible with CMS spread coupon");
             c.setPricer(cmsSpreadCouponPricer);
         }
 
         void PricerSetter::visit(DigitalCmsCoupon& c) {
-            const boost::shared_ptr<CmsCouponPricer> cmsCouponPricer =
-                boost::dynamic_pointer_cast<CmsCouponPricer>(pricer_);
+            const ext::shared_ptr<CmsCouponPricer> cmsCouponPricer =
+                ext::dynamic_pointer_cast<CmsCouponPricer>(pricer_);
             QL_REQUIRE(cmsCouponPricer,
                        "pricer not compatible with CMS coupon");
             c.setPricer(cmsCouponPricer);
         }
 
         void PricerSetter::visit(DigitalCmsSpreadCoupon& c) {
-            const boost::shared_ptr<CmsSpreadCouponPricer> cmsSpreadCouponPricer =
-                boost::dynamic_pointer_cast<CmsSpreadCouponPricer>(pricer_);
+            const ext::shared_ptr<CmsSpreadCouponPricer> cmsSpreadCouponPricer =
+                ext::dynamic_pointer_cast<CmsSpreadCouponPricer>(pricer_);
             QL_REQUIRE(cmsSpreadCouponPricer,
                        "pricer not compatible with CMS spread coupon");
             c.setPricer(cmsSpreadCouponPricer);
         }
 
         void PricerSetter::visit(RangeAccrualFloatersCoupon& c) {
-            const boost::shared_ptr<RangeAccrualPricer> rangeAccrualPricer =
-                boost::dynamic_pointer_cast<RangeAccrualPricer>(pricer_);
+            const ext::shared_ptr<RangeAccrualPricer> rangeAccrualPricer =
+                ext::dynamic_pointer_cast<RangeAccrualPricer>(pricer_);
             QL_REQUIRE(rangeAccrualPricer,
                        "pricer not compatible with range-accrual coupon");
             c.setPricer(rangeAccrualPricer);
         }
 
         void PricerSetter::visit(SubPeriodsCoupon& c) {
-            const boost::shared_ptr<SubPeriodsPricer> subPeriodsPricer =
-                boost::dynamic_pointer_cast<SubPeriodsPricer>(pricer_);
+            const ext::shared_ptr<SubPeriodsPricer> subPeriodsPricer =
+                ext::dynamic_pointer_cast<SubPeriodsPricer>(pricer_);
             QL_REQUIRE(subPeriodsPricer,
                        "pricer not compatible with sub-period coupon");
             c.setPricer(subPeriodsPricer);
         }
 
         void setCouponPricersFirstMatching(const Leg& leg,
-                                           const std::vector<boost::shared_ptr<FloatingRateCouponPricer> >& p) {
+                                           const std::vector<ext::shared_ptr<FloatingRateCouponPricer> >& p) {
             std::vector<PricerSetter> setter;
-            for (Size i = 0; i < p.size(); ++i) {
-                setter.push_back(PricerSetter(p[i]));
+            setter.reserve(p.size());
+            for (const auto& i : p) {
+                setter.emplace_back(i);
             }
-            for (Size i = 0; i < leg.size(); ++i) {
+            for (const auto& i : leg) {
                 Size j = 0;
                 do {
                     try {
-                        leg[i]->accept(setter[j]);
+                        i->accept(setter[j]);
                         j = p.size();
                     } catch (...) {
                         ++j;
@@ -349,16 +348,16 @@ namespace QuantLib {
 
     } // anonymous namespace
 
-    void setCouponPricer(const Leg& leg, const boost::shared_ptr<FloatingRateCouponPricer>& pricer) {
+    void setCouponPricer(const Leg& leg, const ext::shared_ptr<FloatingRateCouponPricer>& pricer) {
             PricerSetter setter(pricer);
-            for (Size i = 0; i < leg.size(); ++i) {
-                leg[i]->accept(setter);
+            for (const auto& i : leg) {
+                i->accept(setter);
             }
     }
 
     void setCouponPricers(
             const Leg& leg,
-            const std::vector<boost::shared_ptr<FloatingRateCouponPricer> >&
+            const std::vector<ext::shared_ptr<FloatingRateCouponPricer> >&
                                                                     pricers) {
         Size nCashFlows = leg.size();
         QL_REQUIRE(nCashFlows>0, "no cashflows");
@@ -376,9 +375,9 @@ namespace QuantLib {
 
     void setCouponPricers(
             const Leg& leg,
-            const boost::shared_ptr<FloatingRateCouponPricer>& p1,
-            const boost::shared_ptr<FloatingRateCouponPricer>& p2) {
-        std::vector<boost::shared_ptr<FloatingRateCouponPricer> > p;
+            const ext::shared_ptr<FloatingRateCouponPricer>& p1,
+            const ext::shared_ptr<FloatingRateCouponPricer>& p2) {
+        std::vector<ext::shared_ptr<FloatingRateCouponPricer> > p;
         p.push_back(p1);
         p.push_back(p2);
         setCouponPricersFirstMatching(leg, p);
@@ -386,10 +385,10 @@ namespace QuantLib {
 
     void setCouponPricers(
             const Leg& leg,
-            const boost::shared_ptr<FloatingRateCouponPricer>& p1,
-            const boost::shared_ptr<FloatingRateCouponPricer>& p2,
-            const boost::shared_ptr<FloatingRateCouponPricer>& p3) {
-        std::vector<boost::shared_ptr<FloatingRateCouponPricer> > p;
+            const ext::shared_ptr<FloatingRateCouponPricer>& p1,
+            const ext::shared_ptr<FloatingRateCouponPricer>& p2,
+            const ext::shared_ptr<FloatingRateCouponPricer>& p3) {
+        std::vector<ext::shared_ptr<FloatingRateCouponPricer> > p;
         p.push_back(p1);
         p.push_back(p2);
         p.push_back(p3);
@@ -398,11 +397,11 @@ namespace QuantLib {
 
     void setCouponPricers(
             const Leg& leg,
-            const boost::shared_ptr<FloatingRateCouponPricer>& p1,
-            const boost::shared_ptr<FloatingRateCouponPricer>& p2,
-            const boost::shared_ptr<FloatingRateCouponPricer>& p3,
-            const boost::shared_ptr<FloatingRateCouponPricer>& p4) {
-        std::vector<boost::shared_ptr<FloatingRateCouponPricer> > p;
+            const ext::shared_ptr<FloatingRateCouponPricer>& p1,
+            const ext::shared_ptr<FloatingRateCouponPricer>& p2,
+            const ext::shared_ptr<FloatingRateCouponPricer>& p3,
+            const ext::shared_ptr<FloatingRateCouponPricer>& p4) {
+        std::vector<ext::shared_ptr<FloatingRateCouponPricer> > p;
         p.push_back(p1);
         p.push_back(p2);
         p.push_back(p3);
