@@ -18,36 +18,40 @@
  FOR A PARTICULAR PURPOSE.  See the license for more details.
 */
 
-#include <ql/termstructures/yield/oisratehelper.hpp>
 #include <ql/instruments/makeois.hpp>
 #include <ql/pricingengines/swap/discountingswapengine.hpp>
+#include <ql/termstructures/yield/oisratehelper.hpp>
 #include <ql/utilities/null_deleter.hpp>
+#include <utility>
 
 namespace QuantLib {
 
-    OISRateHelper::OISRateHelper(
-                    Natural settlementDays,
-                    const Period& tenor, // swap maturity
-                    const Handle<Quote>& fixedRate,
-                    const ext::shared_ptr<OvernightIndex>& overnightIndex,
-                    const Handle<YieldTermStructure>& discount,
-                    bool telescopicValueDates,
-                    Natural paymentLag,
-                    BusinessDayConvention paymentConvention,
-                    Frequency paymentFrequency,
-                    const Calendar& paymentCalendar,
-                    const Period& forwardStart, 
-                    const Spread overnightSpread)
-    : RelativeDateRateHelper(fixedRate),
-      settlementDays_(settlementDays), tenor_(tenor),
-      overnightIndex_(overnightIndex), discountHandle_(discount),
-      telescopicValueDates_(telescopicValueDates),
+    OISRateHelper::OISRateHelper(Natural settlementDays,
+                                 const Period& tenor, // swap maturity
+                                 const Handle<Quote>& fixedRate,
+                                 ext::shared_ptr<OvernightIndex> overnightIndex,
+                                 Handle<YieldTermStructure> discount,
+                                 bool telescopicValueDates,
+                                 Natural paymentLag,
+                                 BusinessDayConvention paymentConvention,
+                                 Frequency paymentFrequency,
+                                 Calendar paymentCalendar,
+                                 const Period& forwardStart,
+                                 const Spread overnightSpread,
+                                 Pillar::Choice pillar,
+                                 Date customPillarDate,
+                                 RateAveraging::Type averagingMethod)
+    : RelativeDateRateHelper(fixedRate), pillarChoice_(pillar), settlementDays_(settlementDays),
+      tenor_(tenor), overnightIndex_(std::move(overnightIndex)),
+      discountHandle_(std::move(discount)), telescopicValueDates_(telescopicValueDates),
       paymentLag_(paymentLag), paymentConvention_(paymentConvention),
-      paymentFrequency_(paymentFrequency),
-      paymentCalendar_(paymentCalendar),
-      forwardStart_(forwardStart), overnightSpread_(overnightSpread) {
+      paymentFrequency_(paymentFrequency), paymentCalendar_(std::move(paymentCalendar)),
+      forwardStart_(forwardStart), overnightSpread_(overnightSpread),
+      averagingMethod_(averagingMethod) {
         registerWith(overnightIndex_);
         registerWith(discountHandle_);
+
+        pillarDate_ = customPillarDate;
         initializeDates();
     }
 
@@ -70,11 +74,38 @@ namespace QuantLib {
             .withPaymentAdjustment(paymentConvention_)
             .withPaymentFrequency(paymentFrequency_)
             .withPaymentCalendar(paymentCalendar_)
-            .withOvernightLegSpread(overnightSpread_);
+            .withOvernightLegSpread(overnightSpread_)
+            .withAveragingMethod(averagingMethod_);
 
         earliestDate_ = swap_->startDate();
+        maturityDate_ = swap_->maturityDate();
+
         Date lastPaymentDate = std::max(swap_->overnightLeg().back()->date(),
                                         swap_->fixedLeg().back()->date());
+        latestRelevantDate_ = std::max(maturityDate_, lastPaymentDate);
+
+        switch (pillarChoice_) {
+          case Pillar::MaturityDate:
+            pillarDate_ = maturityDate_;
+            break;
+          case Pillar::LastRelevantDate:
+            pillarDate_ = latestRelevantDate_;
+            break;
+          case Pillar::CustomDate:
+            // pillarDate_ already assigned at construction time
+            QL_REQUIRE(pillarDate_ >= earliestDate_,
+                       "pillar date (" << pillarDate_ << ") must be later "
+                       "than or equal to the instrument's earliest date (" <<
+                       earliestDate_ << ")");
+            QL_REQUIRE(pillarDate_ <= latestRelevantDate_,
+                       "pillar date (" << pillarDate_ << ") must be before "
+                       "or equal to the instrument's latest relevant date (" <<
+                       latestRelevantDate_ << ")");
+            break;
+          default:
+            QL_FAIL("unknown Pillar::Choice(" << Integer(pillarChoice_) << ")");
+        }
+
         latestDate_ = std::max(swap_->maturityDate(), lastPaymentDate);
     }
 
@@ -95,30 +126,30 @@ namespace QuantLib {
     }
 
     Real OISRateHelper::impliedQuote() const {
-        QL_REQUIRE(termStructure_ != 0, "term structure not set");
+        QL_REQUIRE(termStructure_ != nullptr, "term structure not set");
         // we didn't register as observers - force calculation
         swap_->recalculate();
         return swap_->fairRate();
     }
 
     void OISRateHelper::accept(AcyclicVisitor& v) {
-        Visitor<OISRateHelper>* v1 =
-            dynamic_cast<Visitor<OISRateHelper>*>(&v);
-        if (v1 != 0)
+        auto* v1 = dynamic_cast<Visitor<OISRateHelper>*>(&v);
+        if (v1 != nullptr)
             v1->visit(*this);
         else
             RateHelper::accept(v);
     }
 
-    DatedOISRateHelper::DatedOISRateHelper(
-                    const Date& startDate,
-                    const Date& endDate,
-                    const Handle<Quote>& fixedRate,
-                    const ext::shared_ptr<OvernightIndex>& overnightIndex,
-                    const Handle<YieldTermStructure>& discount,
-                    bool telescopicValueDates)
-        : RateHelper(fixedRate), discountHandle_(discount),
-          telescopicValueDates_(telescopicValueDates) {
+    DatedOISRateHelper::DatedOISRateHelper(const Date& startDate,
+                                           const Date& endDate,
+                                           const Handle<Quote>& fixedRate,
+                                           const ext::shared_ptr<OvernightIndex>& overnightIndex,
+                                           Handle<YieldTermStructure> discount,
+                                           bool telescopicValueDates, 
+                                           RateAveraging::Type averagingMethod)
+    : RateHelper(fixedRate), discountHandle_(std::move(discount)),
+      telescopicValueDates_(telescopicValueDates), 
+      averagingMethod_(averagingMethod) {
 
         registerWith(overnightIndex);
         registerWith(discountHandle_);
@@ -136,7 +167,8 @@ namespace QuantLib {
             .withDiscountingTermStructure(discountRelinkableHandle_)
             .withEffectiveDate(startDate)
             .withTerminationDate(endDate)
-            .withTelescopicValueDates(telescopicValueDates_);
+            .withTelescopicValueDates(telescopicValueDates_)
+            .withAveragingMethod(averagingMethod_);
 
         earliestDate_ = swap_->startDate();
         Date lastPaymentDate = std::max(swap_->overnightLeg().back()->date(),
@@ -161,16 +193,15 @@ namespace QuantLib {
     }
 
     Real DatedOISRateHelper::impliedQuote() const {
-        QL_REQUIRE(termStructure_ != 0, "term structure not set");
+        QL_REQUIRE(termStructure_ != nullptr, "term structure not set");
         // we didn't register as observers - force calculation
         swap_->deepUpdate();
         return swap_->fairRate();
     }
 
     void DatedOISRateHelper::accept(AcyclicVisitor& v) {
-        Visitor<DatedOISRateHelper>* v1 =
-            dynamic_cast<Visitor<DatedOISRateHelper>*>(&v);
-        if (v1 != 0)
+        auto* v1 = dynamic_cast<Visitor<DatedOISRateHelper>*>(&v);
+        if (v1 != nullptr)
             v1->visit(*this);
         else
             RateHelper::accept(v);
