@@ -30,6 +30,7 @@
 #include <ql/time/calendars/target.hpp>
 #include <ql/time/daycounters/actualactual.hpp>
 #include <ql/time/schedule.hpp>
+#include <ql/indexes/ibor/euribor.hpp>
 #include <ql/indexes/ibor/usdlibor.hpp>
 #include <ql/settings.hpp>
 
@@ -49,7 +50,8 @@ void CashFlowsTest::testSettings() {
 
     // cash flows at T+0, T+1, T+2
     std::vector<ext::shared_ptr<CashFlow> > leg;
-    for (Integer i=0; i<3; ++i)
+    leg.reserve(3);
+    for (Integer i = 0; i < 3; ++i)
         leg.push_back(ext::shared_ptr<CashFlow>(new SimpleCashFlow(1.0, today+i)));
 
 
@@ -266,6 +268,89 @@ void CashFlowsTest::testNullFixingDays() {
         .withFixingDays(Null<Natural>());
 }
 
+void CashFlowsTest::testExCouponDates() {
+    BOOST_TEST_MESSAGE("Testing ex-coupon date calculation...");
+
+    Date today = Date::todaysDate();
+    Schedule schedule = MakeSchedule()
+                            .from(today)
+                            .to(today + 5 * Years)
+                            .withFrequency(Monthly)
+                            .withCalendar(TARGET())
+                            .withConvention(Following);
+
+    // no ex-coupon dates
+    Leg l1 = FixedRateLeg(schedule).withNotionals(100.0).withCouponRates(0.03, Actual360());
+    for (auto& i : l1) {
+        ext::shared_ptr<Coupon> c = ext::dynamic_pointer_cast<Coupon>(i);
+        if (c->exCouponDate() != Date()) {
+            BOOST_ERROR("ex-coupon date found (none expected)");
+        }
+    }
+
+    // same for floating legs
+    ext::shared_ptr<IborIndex> index(new Euribor3M);
+    Leg l2 = IborLeg(schedule, index).withNotionals(100.0);
+    for (auto& i : l2) {
+        ext::shared_ptr<Coupon> c = ext::dynamic_pointer_cast<Coupon>(i);
+        if (c->exCouponDate() != Date()) {
+            BOOST_ERROR("ex-coupon date found (none expected)");
+        }
+    }
+
+    // calendar days
+    Leg l5 = FixedRateLeg(schedule)
+                 .withNotionals(100.0)
+                 .withCouponRates(0.03, Actual360())
+                 .withExCouponPeriod(Period(2, Days), NullCalendar(), Unadjusted, false);
+    for (auto& i : l5) {
+        ext::shared_ptr<Coupon> c = ext::dynamic_pointer_cast<Coupon>(i);
+        Date expected = c->accrualEndDate() - 2;
+        if (c->exCouponDate() != expected) {
+            BOOST_ERROR("ex-coupon date = " << c->exCouponDate() << " (" << expected
+                                            << " expected)");
+        }
+    }
+
+    Leg l6 = IborLeg(schedule, index)
+                 .withNotionals(100.0)
+                 .withExCouponPeriod(Period(2, Days), NullCalendar(), Unadjusted, false);
+    for (auto& i : l6) {
+        ext::shared_ptr<Coupon> c = ext::dynamic_pointer_cast<Coupon>(i);
+        Date expected = c->accrualEndDate() - 2;
+        if (c->exCouponDate() != expected) {
+            BOOST_ERROR("ex-coupon date = " << c->exCouponDate() << " (" << expected
+                                            << " expected)");
+        }
+    }
+
+    // business days
+    Leg l7 = FixedRateLeg(schedule)
+                 .withNotionals(100.0)
+                 .withCouponRates(0.03, Actual360())
+                 .withExCouponPeriod(Period(2, Days), TARGET(), Preceding, false);
+    for (auto& i : l7) {
+        ext::shared_ptr<Coupon> c = ext::dynamic_pointer_cast<Coupon>(i);
+        Date expected = TARGET().advance(c->accrualEndDate(), -2, Days);
+        if (c->exCouponDate() != expected) {
+            BOOST_ERROR("ex-coupon date = " << c->exCouponDate() << " (" << expected
+                                            << " expected)");
+        }
+    }
+
+    Leg l8 = IborLeg(schedule, index)
+                 .withNotionals(100.0)
+                 .withExCouponPeriod(Period(2, Days), TARGET(), Preceding, false);
+    for (auto& i : l8) {
+        ext::shared_ptr<Coupon> c = ext::dynamic_pointer_cast<Coupon>(i);
+        Date expected = TARGET().advance(c->accrualEndDate(), -2, Days);
+        if (c->exCouponDate() != expected) {
+            BOOST_ERROR("ex-coupon date = " << c->exCouponDate() << " (" << expected
+                                            << " expected)");
+        }
+    }
+}
+
 void CashFlowsTest::testIrregularFirstCouponReferenceDatesAtEndOfMonth() {
     BOOST_TEST_MESSAGE("Testing irregular first coupon reference dates with end of month enabled...");
     Schedule schedule =
@@ -343,8 +428,8 @@ void CashFlowsTest::testPartialScheduleLegConstruction() {
         ext::dynamic_pointer_cast<FixedRateCoupon>(leg.front());
     ext::shared_ptr<FixedRateCoupon> lastCpn =
         ext::dynamic_pointer_cast<FixedRateCoupon>(leg.back());
-    BOOST_REQUIRE(firstCpn != NULL);
-    BOOST_REQUIRE(lastCpn != NULL);
+    BOOST_REQUIRE(firstCpn != nullptr);
+    BOOST_REQUIRE(lastCpn != nullptr);
     BOOST_CHECK_EQUAL(firstCpn->referencePeriodStart(), Date(25, Mar, 2017));
     BOOST_CHECK_EQUAL(firstCpn->referencePeriodEnd(), Date(25, Sep, 2017));
     BOOST_CHECK_EQUAL(lastCpn->referencePeriodStart(), Date(25, Sep, 2020));
@@ -354,8 +439,8 @@ void CashFlowsTest::testPartialScheduleLegConstruction() {
         ext::dynamic_pointer_cast<FixedRateCoupon>(leg2.front());
     ext::shared_ptr<FixedRateCoupon> lastCpn2 =
         ext::dynamic_pointer_cast<FixedRateCoupon>(leg2.back());
-    BOOST_REQUIRE(firstCpn2 != NULL);
-    BOOST_REQUIRE(lastCpn2 != NULL);
+    BOOST_REQUIRE(firstCpn2 != nullptr);
+    BOOST_REQUIRE(lastCpn2 != nullptr);
     BOOST_CHECK_EQUAL(firstCpn2->referencePeriodStart(), Date(25, Mar, 2017));
     BOOST_CHECK_EQUAL(firstCpn2->referencePeriodEnd(), Date(25, Sep, 2017));
     BOOST_CHECK_EQUAL(lastCpn2->referencePeriodStart(), Date(25, Sep, 2020));
@@ -365,8 +450,8 @@ void CashFlowsTest::testPartialScheduleLegConstruction() {
         ext::dynamic_pointer_cast<FixedRateCoupon>(leg3.front());
     ext::shared_ptr<FixedRateCoupon> lastCpn3 =
         ext::dynamic_pointer_cast<FixedRateCoupon>(leg3.back());
-    BOOST_REQUIRE(firstCpn3 != NULL);
-    BOOST_REQUIRE(lastCpn3 != NULL);
+    BOOST_REQUIRE(firstCpn3 != nullptr);
+    BOOST_REQUIRE(lastCpn3 != nullptr);
     BOOST_CHECK_EQUAL(firstCpn3->referencePeriodStart(), Date(15, Sep, 2017));
     BOOST_CHECK_EQUAL(firstCpn3->referencePeriodEnd(), Date(25, Sep, 2017));
     BOOST_CHECK_EQUAL(lastCpn3->referencePeriodStart(), Date(25, Sep, 2020));
@@ -389,8 +474,8 @@ void CashFlowsTest::testPartialScheduleLegConstruction() {
         ext::dynamic_pointer_cast<FloatingRateCoupon>(legf.front());
     ext::shared_ptr<FloatingRateCoupon> lastCpnF =
         ext::dynamic_pointer_cast<FloatingRateCoupon>(legf.back());
-    BOOST_REQUIRE(firstCpnF != NULL);
-    BOOST_REQUIRE(lastCpnF != NULL);
+    BOOST_REQUIRE(firstCpnF != nullptr);
+    BOOST_REQUIRE(lastCpnF != nullptr);
     BOOST_CHECK_EQUAL(firstCpnF->referencePeriodStart(), Date(25, Mar, 2017));
     BOOST_CHECK_EQUAL(firstCpnF->referencePeriodEnd(), Date(25, Sep, 2017));
     BOOST_CHECK_EQUAL(lastCpnF->referencePeriodStart(), Date(25, Sep, 2020));
@@ -400,8 +485,8 @@ void CashFlowsTest::testPartialScheduleLegConstruction() {
         ext::dynamic_pointer_cast<FloatingRateCoupon>(legf2.front());
     ext::shared_ptr<FloatingRateCoupon> lastCpnF2 =
         ext::dynamic_pointer_cast<FloatingRateCoupon>(legf2.back());
-    BOOST_REQUIRE(firstCpnF2 != NULL);
-    BOOST_REQUIRE(lastCpnF2 != NULL);
+    BOOST_REQUIRE(firstCpnF2 != nullptr);
+    BOOST_REQUIRE(lastCpnF2 != nullptr);
     BOOST_CHECK_EQUAL(firstCpnF2->referencePeriodStart(), Date(25, Mar, 2017));
     BOOST_CHECK_EQUAL(firstCpnF2->referencePeriodEnd(), Date(25, Sep, 2017));
     BOOST_CHECK_EQUAL(lastCpnF2->referencePeriodStart(), Date(25, Sep, 2020));
@@ -411,8 +496,8 @@ void CashFlowsTest::testPartialScheduleLegConstruction() {
         ext::dynamic_pointer_cast<FloatingRateCoupon>(legf3.front());
     ext::shared_ptr<FloatingRateCoupon> lastCpnF3 =
         ext::dynamic_pointer_cast<FloatingRateCoupon>(legf3.back());
-    BOOST_REQUIRE(firstCpnF3 != NULL);
-    BOOST_REQUIRE(lastCpnF3 != NULL);
+    BOOST_REQUIRE(firstCpnF3 != nullptr);
+    BOOST_REQUIRE(lastCpnF3 != nullptr);
     BOOST_CHECK_EQUAL(firstCpnF3->referencePeriodStart(), Date(15, Sep, 2017));
     BOOST_CHECK_EQUAL(firstCpnF3->referencePeriodEnd(), Date(25, Sep, 2017));
     BOOST_CHECK_EQUAL(lastCpnF3->referencePeriodStart(), Date(25, Sep, 2020));
@@ -420,10 +505,11 @@ void CashFlowsTest::testPartialScheduleLegConstruction() {
 }
 
 test_suite* CashFlowsTest::suite() {
-    test_suite* suite = BOOST_TEST_SUITE("Cash flows tests");
+    auto* suite = BOOST_TEST_SUITE("Cash flows tests");
     suite->add(QUANTLIB_TEST_CASE(&CashFlowsTest::testSettings));
     suite->add(QUANTLIB_TEST_CASE(&CashFlowsTest::testAccessViolation));
     suite->add(QUANTLIB_TEST_CASE(&CashFlowsTest::testDefaultSettlementDate));
+    suite->add(QUANTLIB_TEST_CASE(&CashFlowsTest::testExCouponDates));
     if (IborCoupon::usingAtParCoupons())
         suite->add(QUANTLIB_TEST_CASE(&CashFlowsTest::testNullFixingDays));
 
