@@ -43,6 +43,8 @@
 #include <ql/cashflows/fixedratecoupon.hpp>
 #include <ql/instruments/yearonyearinflationswap.hpp>
 
+#include <functional>
+
 
 using boost::unit_test_framework::test_suite;
 
@@ -72,24 +74,17 @@ namespace inflation_test {
             new FlatForward(evaluationDate, 0.05, Actual360()));
     }
 
-    template <class T, class U, class I>
-    std::vector<ext::shared_ptr<BootstrapHelper<T> > >
-    makeHelpers(const std::vector<Datum>& iiData,
-                const ext::shared_ptr<I>& ii,
-                const Period& observationLag,
-                const Calendar& calendar,
-                const BusinessDayConvention& bdc,
-                const DayCounter& dc,
-                const Handle<YieldTermStructure>& yTS) {
+    template <class T>
+    std::vector<ext::shared_ptr<BootstrapHelper<T> > > makeHelpers(
+        const std::vector<Datum>& iiData,
+        std::function<ext::shared_ptr<BootstrapHelper<T> >(const Handle<Quote>&, const Date&)>
+            makeHelper) {
 
         std::vector<ext::shared_ptr<BootstrapHelper<T> > > instruments;
         for (Datum datum : iiData) {
             Date maturity = datum.date;
-            Handle<Quote> quote(ext::shared_ptr<Quote>(
-                new SimpleQuote(datum.rate/100.0)));
-            ext::shared_ptr<BootstrapHelper<T> > anInstrument(new U(
-                quote, observationLag, maturity,
-                calendar, bdc, dc, ii, yTS));
+            Handle<Quote> quote(ext::shared_ptr<Quote>(new SimpleQuote(datum.rate / 100.0)));
+            auto anInstrument = makeHelper(quote, maturity);
             instruments.push_back(anInstrument);
         }
 
@@ -364,14 +359,15 @@ void InflationTest::testZeroTermStructure() {
     };
 
     Period observationLag = Period(2,Months);
-    DayCounter dc = Thirty360();
+    DayCounter dc = Thirty360(Thirty360::BondBasis);
     Frequency frequency = Monthly;
-    std::vector<ext::shared_ptr<BootstrapHelper<ZeroInflationTermStructure> > > helpers =
-    makeHelpers<ZeroInflationTermStructure,ZeroCouponInflationSwapHelper,
-                ZeroInflationIndex>(zcData, ii,
-                                    observationLag,
-                                    calendar, bdc, dc,
-                                    Handle<YieldTermStructure>(nominalTS));
+
+    auto makeHelper = [&](const Handle<Quote>& quote, const Date& maturity) {
+        return ext::make_shared<ZeroCouponInflationSwapHelper>(
+            quote, observationLag, maturity, calendar, bdc, dc, ii, CPI::AsIndex,
+            Handle<YieldTermStructure>(nominalTS));
+    };
+    auto helpers = makeHelpers<ZeroInflationTermStructure>(zcData, makeHelper);
 
     Rate baseZeroRate = zcData[0].rate/100.0;
     ext::shared_ptr<PiecewiseZeroInflationCurve<Linear> > pZITS(
@@ -414,7 +410,7 @@ void InflationTest::testZeroTermStructure() {
     // we are testing UKRPI which is not interpolated
     Date bd = hz->baseDate();
     Real bf = ii->fixing(bd);
-    for (auto d : testIndex) {
+    for (const auto& d : testIndex) {
         Real z = hz->zeroRate(d, Period(0, Days));
         Real t = hz->dayCounter().yearFraction(bd, d);
         if(!ii->interpolated()) // because fixing constant over period
@@ -459,12 +455,12 @@ void InflationTest::testZeroTermStructure() {
 
     ext::shared_ptr<ZeroInflationIndex> zii = ext::dynamic_pointer_cast<ZeroInflationIndex>(ii);
     BOOST_REQUIRE_MESSAGE(zii,"dynamic_pointer_cast to ZeroInflationIndex from UKRPI failed");
-    ZeroCouponInflationSwap nzcis(ZeroCouponInflationSwap::Payer,
-                                     1000000.0,
-                                     evaluationDate,
-                                     zcData[6].date,    // end date = maturity
-                                     calendar, bdc, dc, zcData[6].rate/100.0, // fixed rate
-                                     zii, observationLag);
+    ZeroCouponInflationSwap nzcis(Swap::Payer,
+                                  1000000.0,
+                                  evaluationDate,
+                                  zcData[6].date,    // end date = maturity
+                                  calendar, bdc, dc, zcData[6].rate/100.0, // fixed rate
+                                  zii, observationLag, CPI::AsIndex);
 
     // N.B. no coupon pricer because it is not a coupon, effect of inflation curve via
     //      inflation curve attached to the inflation index.
@@ -501,12 +497,13 @@ void InflationTest::testZeroTermStructure() {
     // now build the zero inflation curve
     // same data, bigger lag or it will be a self-contradiction
     Period observationLagyes = Period(3,Months);
-    std::vector<ext::shared_ptr<BootstrapHelper<ZeroInflationTermStructure> > > helpersyes =
-    makeHelpers<ZeroInflationTermStructure,ZeroCouponInflationSwapHelper,
-    ZeroInflationIndex>(zcData, iiyes,
-                        observationLagyes,
-                        calendar, bdc, dc,
-                        Handle<YieldTermStructure>(nominalTS));
+
+    auto makeHelperYes = [&](const Handle<Quote>& quote, const Date& maturity) {
+        return ext::make_shared<ZeroCouponInflationSwapHelper>(
+            quote, observationLagyes, maturity, calendar, bdc, dc, iiyes, CPI::AsIndex,
+            Handle<YieldTermStructure>(nominalTS));
+    };
+    auto helpersyes = makeHelpers<ZeroInflationTermStructure>(zcData, makeHelperYes);
 
     ext::shared_ptr<PiecewiseZeroInflationCurve<Linear> > pZITSyes(
             new PiecewiseZeroInflationCurve<Linear>(
@@ -548,7 +545,7 @@ void InflationTest::testZeroTermStructure() {
     // we are testing UKRPI which is FAKE interpolated for testing here
     bd = hz->baseDate();
     bf = iiyes->fixing(bd);
-    for (auto d : testIndex) {
+    for (const auto& d : testIndex) {
         Real z = hz->zeroRate(d, Period(0, Days));
         Real t = hz->dayCounter().yearFraction(bd, d);
         Real calc = bf * pow( 1+z, t);
@@ -569,12 +566,12 @@ void InflationTest::testZeroTermStructure() {
 
     ext::shared_ptr<ZeroInflationIndex> ziiyes = ext::dynamic_pointer_cast<ZeroInflationIndex>(iiyes);
     BOOST_REQUIRE_MESSAGE(ziiyes,"dynamic_pointer_cast to ZeroInflationIndex from UKRPI-I failed");
-    ZeroCouponInflationSwap nzcisyes(ZeroCouponInflationSwap::Payer,
+    ZeroCouponInflationSwap nzcisyes(Swap::Payer,
                                      1000000.0,
                                      evaluationDate,
                                      zcData[6].date,    // end date = maturity
                                      calendar, bdc, dc, zcData[6].rate/100.0, // fixed rate
-                                     ziiyes, observationLagyes);
+                                     ziiyes, observationLagyes, CPI::AsIndex);
 
     // N.B. no coupon pricer because it is not a coupon, effect of inflation curve via
     //      inflation curve attached to the inflation index.
@@ -854,15 +851,15 @@ void InflationTest::testYYTermStructure() {
     };
 
     Period observationLag = Period(2,Months);
-    DayCounter dc = Thirty360();
+    DayCounter dc = Thirty360(Thirty360::BondBasis);
 
     // now build the helpers ...
-    std::vector<ext::shared_ptr<BootstrapHelper<YoYInflationTermStructure> > > helpers =
-    makeHelpers<YoYInflationTermStructure,YearOnYearInflationSwapHelper,
-    YoYInflationIndex>(yyData, iir,
-                       observationLag,
-                       calendar, bdc, dc,
-                       Handle<YieldTermStructure>(nominalTS));
+    auto makeHelper = [&](const Handle<Quote>& quote, const Date& maturity) {
+        return ext::make_shared<YearOnYearInflationSwapHelper>(
+            quote, observationLag, maturity, calendar, bdc, dc, iir,
+            Handle<YieldTermStructure>(nominalTS));
+    };
+    auto helpers = makeHelpers<YoYInflationTermStructure>(yyData, makeHelper);
 
     Rate baseYYRate = yyData[0].rate/100.0;
     ext::shared_ptr<PiecewiseYoYInflationCurve<Linear> > pYYTS(
@@ -879,8 +876,6 @@ void InflationTest::testYYTermStructure() {
     // usual swap engine
     Handle<YieldTermStructure> hTS(nominalTS);
     ext::shared_ptr<PricingEngine> sppe(new DiscountingSwapEngine(hTS));
-    ext::shared_ptr<InflationCouponPricer> pricer =
-        ext::make_shared<YoYInflationCouponPricer>(hTS);
 
     // make sure that the index has the latest yoy term structure
     hy.linkTo(pYYTS);
@@ -896,21 +891,19 @@ void InflationTest::testYYTermStructure() {
         .backwards()
         ;
 
-        YearOnYearInflationSwap yyS2(YearOnYearInflationSwap::Payer,
-                                        1000000.0,
-                                        yoySchedule,//fixed schedule, but same as yoy
-                                        yyData[j].rate/100.0,
-                                        dc,
-                                        yoySchedule,
-                                        iir,
-                                        observationLag,
-                                        0.0,        //spread on index
-                                        dc,
-                                        UnitedKingdom());
+        YearOnYearInflationSwap yyS2(Swap::Payer,
+                                     1000000.0,
+                                     yoySchedule,//fixed schedule, but same as yoy
+                                     yyData[j].rate/100.0,
+                                     dc,
+                                     yoySchedule,
+                                     iir,
+                                     observationLag,
+                                     0.0,        //spread on index
+                                     dc,
+                                     UnitedKingdom());
 
         yyS2.setPricingEngine(sppe);
-        setCouponPricer(yyS2.yoyLeg(), pricer);
-
 
         BOOST_CHECK_MESSAGE(fabs(yyS2.NPV())<eps,"fresh yoy swap NPV!=0 from TS "
                 <<"swap quote for pt " << j
@@ -934,20 +927,19 @@ void InflationTest::testYYTermStructure() {
         .backwards()
         ;
 
-        YearOnYearInflationSwap yyS3(YearOnYearInflationSwap::Payer,
-                                    1000000.0,
-                                    yoySchedule,//fixed schedule, but same as yoy
-                                    yyData[jj].rate/100.0,
-                                    dc,
-                                    yoySchedule,
-                                    iir,
-                                    observationLag,
-                                    0.0,        //spread on index
-                                    dc,
-                                    UnitedKingdom());
+        YearOnYearInflationSwap yyS3(Swap::Payer,
+                                     1000000.0,
+                                     yoySchedule,//fixed schedule, but same as yoy
+                                     yyData[jj].rate/100.0,
+                                     dc,
+                                     yoySchedule,
+                                     iir,
+                                     observationLag,
+                                     0.0,        //spread on index
+                                     dc,
+                                     UnitedKingdom());
 
         yyS3.setPricingEngine(sppe);
-        setCouponPricer(yyS3.yoyLeg(), pricer);
 
         BOOST_CHECK_MESSAGE(fabs(yyS3.NPV())< 20000.0,
                             "unexpected size of aged YoY swap, aged "
